/////////////////////////////////////
//  Generated Initialization File  //
/////////////////////////////////////

#include "C8051F120.h"
#include <stdio.h>

 //-----------------------------------------------------------------------------
// Function PROTOTYPES
//-----------------------------------------------------------------------------

void Port_IO_Init (void);
void UART0_Init (void);

//-----------------------------------------------------------------------------
// Global CONSTANTS
//-----------------------------------------------------------------------------

#define BAUDRATE     115200            //Baud rate of UART in bps
#define INTCLK       24500000          //Internal oscillator frequency in Hz
#define SYSCLK       49000000          //Output of PLL derived from (INTCLK*2)

sbit LED = P1^6;                       //LED='1' means ON

// Peripheral specific initialization functions,
// Called from the Init_Device() function
void Oscillator_Init()
{
    int i = 0;
    SFRPAGE   = CONFIG_PAGE;
    OSCICN    = 0x83;				   	//set internal oscillator to run
                                       	//at its maximum frequency
    CCH0CN    &= ~0x20;		  			//disable cache prefetch
    SFRPAGE   = LEGACY_PAGE;
    FLSCL     = 0x10;					//set flash read timing for <= 50MHz
    SFRPAGE   = CONFIG_PAGE;
    CCH0CN    |= 0x20;					//enable cache prefetch
    PLL0CN    |= 0x01;	 				//power up PLL
    PLL0DIV   = 0x01;					//PLL pre-divider = 1:1
    PLL0FLT   = 0x21;					//PLL output clock = 30-60 MHz
										//PLL reference clock = 19-30 MHz
    PLL0MUL   = 0x02;					//PLL multiplier = 2X
    for (i = 0; i < 15; i++);  			// Wait 5us for initialization
    PLL0CN    |= 0x02;
    while ((PLL0CN & 0x10) == 0);
    CLKSEL    = 0x02; 					//output = SYSCLK
										//SYSCLK derived from PLL
}
 void Reset_Sources_Init()
{
    WDTCN     = 0xDE;
    WDTCN     = 0xAD;
}
void Timer_Init()
{
    SFRPAGE   = TIMER01_PAGE;
    TCON      = 0x40;					//enable Timer 1
    TMOD      = 0x22;					//set Timer 1 for Mode 2
										//8-bit Counter/Timer with Auto-Reload
    CKCON     = 0x10;					//Timer 1 uses system clock
    TH1       = 0xE5;					//Timer 1 reload value for 115200 bps baud clock
}
//-----------------------------------------------------------------------------
// UART1_Init
//-----------------------------------------------------------------------------
//
void UART0_Init (void)
{

   SFRPAGE = UART0_PAGE;
   SCON0	= 0x40;                     
   SSTA0	= 0x10;
   TI0 = 1;                            // Indicate TX0 ready
}
void Port_IO_Init()
{
    // P0.0  -  TX0 (UART0), Open-Drain, Digital
    // P0.1  -  RX0 (UART0), Open-Drain, Digital
    // P0.2  -  Unassigned,  Open-Drain, Digital
    // P0.3  -  Unassigned,  Open-Drain, Digital
    // P0.4  -  Unassigned,  Open-Drain, Digital
    // P0.5  -  Unassigned,  Open-Drain, Digital
    // P0.6  -  Unassigned,  Open-Drain, Digital
    // P0.7  -  Unassigned,  Open-Drain, Digital

    // P1.0  -  Unassigned,  Open-Drain, Digital
    // P1.1  -  Unassigned,  Open-Drain, Digital
    // P1.2  -  Unassigned,  Open-Drain, Digital
    // P1.3  -  Unassigned,  Open-Drain, Digital
    // P1.4  -  Unassigned,  Open-Drain, Digital
    // P1.5  -  Unassigned,  Open-Drain, Digital
    // P1.6  -  Unassigned,  Push-Pull,  Digital
    // P1.7  -  Unassigned,  Open-Drain, Digital

    // P2.0  -  Unassigned,  Open-Drain, Digital
    // P2.1  -  Unassigned,  Open-Drain, Digital
    // P2.2  -  Unassigned,  Open-Drain, Digital
    // P2.3  -  Unassigned,  Open-Drain, Digital
    // P2.4  -  Unassigned,  Open-Drain, Digital
    // P2.5  -  Unassigned,  Open-Drain, Digital
    // P2.6  -  Unassigned,  Open-Drain, Digital
    // P2.7  -  Unassigned,  Open-Drain, Digital

    // P3.0  -  Unassigned,  Open-Drain, Digital
    // P3.1  -  Unassigned,  Open-Drain, Digital
    // P3.2  -  Unassigned,  Open-Drain, Digital
    // P3.3  -  Unassigned,  Open-Drain, Digital
    // P3.4  -  Unassigned,  Open-Drain, Digital
    // P3.5  -  Unassigned,  Open-Drain, Digital
    // P3.6  -  Unassigned,  Open-Drain, Digital
    // P3.7  -  Unassigned,  Open-Drain, Digital

    SFRPAGE   = CONFIG_PAGE;
    P0MDOUT   = 0x03;
    P1MDOUT   = 0x40;
    XBR0      = 0x04;
    XBR2      = 0x40;
}

// Initialization function for device,
// Call Init_Device() from your main program
void Init_Device(void)
{
    Reset_Sources_Init();
	Oscillator_Init();
	Timer_Init();
	Port_IO_Init();
    UART0_Init();
 
}
void main()
{
	unsigned int x,y;
	//initialize the microcontroller
	Init_Device();
	//initialize the kill-time values
	x = 0xFFFF;
	y = 0x007F;
	//
	SFRPAGE = UART0_PAGE;
	while(1){
		do{
			while(--x);
		}while(--y);
		LED = ~LED;
		x = 0xFFFF;
		y = 0x007F;
		printf("\r\nNUTS AND VOLTS READERS ROCK!\r\n");
 	}
}